@@ -129,6 +129,9 @@ stickynotes_applet_init (PanelApplet *panel_applet)
 
 	stickynotes->notes = NULL;
 	stickynotes->applets = NULL;
+	stickynotes->last_timeout_data = 0;
+
+	g_set_application_name (_("Sticky Notes"));
 
 	/* Register size for icons */
 	gtk_icon_size_register ("stickynotes_icon_size", 8,8);
@@ -150,7 +153,6 @@ stickynotes_applet_init (PanelApplet *panel_applet)
 	stickynotes_make_prelight_icon (stickynotes->icon_prelight,
 			stickynotes->icon_normal, 30);
 	stickynotes->gconf = gconf_client_get_default();
-	stickynotes->tooltips = gtk_tooltips_new();
 
 	stickynotes_applet_init_icons();
 	stickynotes_applet_init_prefs();
@@ -176,17 +178,7 @@ stickynotes_applet_init (PanelApplet *panel_applet)
 	/* Load sticky notes */
 	stickynotes_load (gtk_widget_get_screen (GTK_WIDGET (panel_applet)));
 	
-	/* Auto-save every so minutes (default 5) */
-	timeout = gconf_client_get_int (stickynotes->gconf,
-				GCONF_PATH "/settings/autosave_time", NULL);
-	if (timeout <= 0)
-	{
-		g_warning ("No default timeout, is the schema installed?");
-		timeout = 5;
-	}
-	g_timeout_add (1000 * 60 * timeout,
-		      (GSourceFunc) applet_save_cb, NULL);
-	g_timeout_add (100, applet_check_click_on_desktop_cb, NULL);
+	install_check_click_on_desktop ();
 }
 
 /* Initialize Sticky Notes Icons */
@@ -356,7 +348,6 @@ StickyNotesApplet * stickynotes_applet_new(PanelApplet *panel_applet)
 	/* Initialize Sticky Notes Applet */
 	applet->w_applet = GTK_WIDGET(panel_applet);
 	applet->w_image = gtk_image_new();
-	applet->about_dialog = NULL;
 	applet->destroy_all_dialog = NULL;
 	applet->prelighted = FALSE;
 	applet->pressed = FALSE;
@@ -478,7 +469,6 @@ stickynotes_applet_update_prefs (void)
 
 	if (!font_str)
 	{
-		g_free (font_str);
 		font_str = g_strdup ("Sans 10");
 	}
 
@@ -486,14 +476,12 @@ stickynotes_applet_update_prefs (void)
 			GCONF_PATH "/defaults/color", NULL);
 	if (!color_str)
 	{
-		g_free (color_str);
 		color_str = g_strdup ("#ECF833");
 	}
 	font_color_str = gconf_client_get_string (stickynotes->gconf,
 			GCONF_PATH "/defaults/font_color", NULL);
 	if (!font_color_str)
 	{
-		g_free (font_color_str);
 		font_color_str = g_strdup ("#000000");
 	}
 
@@ -600,8 +588,7 @@ stickynotes_applet_update_tooltips (void)
 	for (l = stickynotes->applets; l; l = l->next)
 	{
 		applet = l->data;
-		gtk_tooltips_set_tip (stickynotes->tooltips,
-				applet->w_applet, tooltip, NULL);
+		gtk_widget_set_tooltip_text (applet->w_applet, tooltip);
 	
 		if (applet->menu_tip)
 			gtk_label_set_text (GTK_LABEL (gtk_bin_get_child (
